How to use — mlyPipeline 0.1 documentation

# How to use

The main functionality is running a search on a provided stream of data. The suggested use of the pipeline is running the search.py script with appropriate options through terminal as it will be shown below.

MLy provides a series of tutorials that will help you understand how to use the package. MLy can help you do two main things.

- Create datasets using the various generator tools, that are related to gravitational wave data or not.
- PlugIns, to create and add your own extra features on the datasets you have already created, that fit to your own problem.
- Tools to test a trained algorithm, assuming you trained a machine learning algorithm (see here for a simple example using keras).

Note

This project and its documentation are under active development.